@@ -1,9 +1,15 @@
 # -*- coding: utf-8 -*-
+from __future__ import unicode_literals, absolute_import
+try:
+    import unittest2 as unittest
+except:
+    import unittest
 
-import unittest
+import six
+import pytest
+
+from pytoxml import PyToXml, Attributes, CData
 
-from lxml import etree
-from pytoxml import *
 
 class TestPyToXml(unittest.TestCase):
     def test_simple_root(self):
@@ -19,6 +25,12 @@ class TestPyToXml(unittest.TestCase):
         p2x.encode()
         self.assertEqual(str(p2x), "<root><one>2</one></root>")
 
+    def test_six_integer_types(self):
+        for six_type in six.integer_types:
+            p2x = PyToXml("root", { "one": six_type(2) })
+            p2x.encode()
+            self.assertEqual(str(p2x), "<root><one>2</one></root>")
+
     def test_float_values(self):
         p2x = PyToXml("root", { "one": 2.3 })
         p2x.encode()
@@ -52,8 +64,8 @@ class TestPyToXml(unittest.TestCase):
         p2x = PyToXml("root", { "a": u"\u2603" })
         p2x.encode()
 
-        output = "<root><a>☃</a></root>"
-        self.assertEqual(str(p2x), output)
+        output = u"<root><a>☃</a></root>"
+        self.assertEqual(six.text_type(p2x), output)
 
     def test_xmldecloration_default_encoding(self):
         p2x = PyToXml("root", "hi", xml_declaration=True)
@@ -79,6 +91,7 @@ class TestPyToXml(unittest.TestCase):
 
         p2x = PyToXml("a", { "b": Exception("Should now serialise") })
         p2x.add_type_handler(Exception, temp_convertor)
+
         self.assertEqual(str(p2x.encode()), "<a><b>Should now serialise</b></a>")
 
     def test_cdata(self):
@@ -114,5 +127,16 @@ class TestPyToXml(unittest.TestCase):
         p2x = PyToXml("a", { }, root_attributes={"one": "two"} )
         self.assertEqual(str(p2x.encode()), "<a one=\"two\"/>")
 
+    def test_illegal_unicode(self):
+        "Illegal unicode errors unless told to escape"
+        p2x = PyToXml("root", {"a": u"\u001a"})
+        with pytest.raises(ValueError):
+            p2x.encode()
+
+        p2x = PyToXml("root", {"a": u"\u001a"}, escape_illegal_chars=True)
+        text = p2x.encode()
+        assert str(text) == "<root><a></a></root>"
+
+
 if __name__ == '__main__':
     unittest.main()
